<?php

use App\Controller\CategoryController;
use App\Controller\IngredientController;
use App\Controller\PizzaController;

spl_autoload_register(function ($class_name) {

    $class_name = str_replace('App\\','',$class_name);

    // Convertir le nom de la classe en chemin de fichier en remplaçant les antislashs par des barres obliques
    $file = '../src/' . str_replace('\\', '/', $class_name) . '.php';

    // Vérifier si le fichier de classe existe
    if (file_exists($file)) {
        // Inclure le fichier de classe
        include_once $file;
    }
});
/**
 * @api
 */

header( 'content-type: text/json; charset=utf-8' );
header( 'Access-Control-Allow-Headers *');

$request_method = $_SERVER["REQUEST_METHOD"];
$path = isset($_GET['path']) ? $_GET['path'] : '';

switch ($path) {
    case 'pizzas':
        $pizzaController = new PizzaController();
        switch ($request_method) {
            case 'GET':
                $response = $pizzaController->getAllPizzas();
                echo json_encode($response);
                break;
            case 'POST':
                // Création d'une nouvelle pizza
                $data = json_decode(file_get_contents("php://input"), true);
                $response = $pizzaController->create($data);
                echo json_encode($response);
                break;
            case 'PUT':
                // Mise à jour d'une pizza existante
                $data = json_decode(file_get_contents("php://input"), true);
                $response = $pizzaController->update($data,$_GET['idPizza']);
                echo json_encode($response);
                break;
            default:
                http_response_code(405);
                echo json_encode(array("message" => "Méthode non autorisée."));
                break;
        }
        break;
    case 'ingredients':
        $ingredientController = new IngredientController();
        switch ($request_method) {
            case 'GET':
                $response = $ingredientController->getByPizza($_GET['idPizza']);
                echo json_encode($response);
                break;
            case 'POST':
                // Création d'un nouvel ingrédient
                $data = json_decode(file_get_contents("php://input"), true);
                $response = $ingredientController->create($data,$_GET['idPizza']);
                echo json_encode($response);
                break;
            case 'PUT':
                // Mise à jour d'un ingrédient existant
                $data = json_decode(file_get_contents("php://input"), true);
                $response = $ingredientController->update($data);
                echo json_encode($response);
                break;
            default:
                http_response_code(405);
                echo json_encode(array("message" => "Méthode non autorisée."));
                break;
        }
        break;
    case 'category':
        $categoryController = new CategoryController();
        switch ($request_method) {
            case 'GET':
                $response = $categoryController->getAllCategory();
                echo json_encode($response);
                break;
            default:
                http_response_code(405);
                echo json_encode(array("message" => "Méthode non autorisée."));
                break;
        }
        break;
    default:
        http_response_code(404); // Page non trouvée
        echo json_encode(array("message" => "page not found"));
        break;
}
