<?php

namespace App\Controller;

use App\Entities\Pizza;
use App\Repositories\CategoryRepository;
use App\Repositories\PizzaRepository;
use App\Service\PizzaService;

class PizzaController
{
    private PizzaRepository $pizzaRepository;
    private CategoryRepository $categoryRepository;
    private PizzaService $pizzaService;

    public function __construct()
    {
        $this->pizzaRepository = new PizzaRepository();
        $this->categoryRepository = new CategoryRepository();
        $this->pizzaService = new PizzaService($this->categoryRepository);
    }

    public function getAllPizzas()
    {

        // Retourne toutes les pizzas
        header('Content-Type: application/json');
        return $this->pizzaRepository->getAllPizzas();
    }

    public function create(array $data): array
    {
        $pizza = $this->pizzaService->create($data);

       if(null !== $pizza){
            $pizzaId = $this->pizzaRepository->createPizza($pizza);
            return ["id" => $pizzaId];
        } else {
            http_response_code(400);
            return array("message" => "Impossible de créer la pizza. Les données sont incomplètes.");
        }
    }

    public function update(array $data,int $idPizza): array
    {
        $pizza = $this->pizzaService->update($data,$idPizza);

        if(null !== $pizza){
            $result = $this->pizzaRepository->updatePizza($pizza);
            if ($result) {
                return ["message" => "Pizza mise à jour avec succès."];
            } else {
                http_response_code(404);
                return ["message" => "La pizza n'a pas été trouvée."];
            }
        } else {
            http_response_code(400);
            return ["message" => "Impossible de mettre à jour la pizza. Les données sont incomplètes."];
        }
    }
}