<?php

namespace App\Repositories;

use App\Entities\Pizza;
use PDO;

class PizzaRepository extends Repository {
    private CategoryRepository $categoryRepository;
    private IngredientRepository $ingredientRepository;

    public function __construct() {
        parent::__construct();
        $this->categoryRepository = new CategoryRepository();
        $this->ingredientRepository = new IngredientRepository();
    }

    public function getAllPizzas() {
        $query = "SELECT id, name, description, price, recipeText, idCategory FROM Pizza";
        $statement = $this->getPdo()->query($query);
        $pizzas = [];
        while ($row = $statement->fetch(PDO::FETCH_ASSOC)) {
            $pizza = new Pizza($row['id'],$row['name'],$row['description'], $row['price'], $row['recipetext']);
            $category = $this->categoryRepository->getCategoryById($row['idcategory']);
            $ingredients = $this->ingredientRepository->getIngredientsForPizza($pizza->id);

            $pizza->category = $category;
            $pizza->ingredients = $ingredients;

            unset($pizza->idCategory);

            $pizzas[] = $pizza;
        }
        return $pizzas;
    }

    public function createPizza(Pizza $pizza): false|string
    {
        $query = "INSERT INTO Pizza (name, description, price, recipeText, idCategory) VALUES (:name, :description, :price, :recipeText, :idCategory)";
        $statement = $this->getPdo()->prepare($query);
        $statement->execute([
            'name' => $pizza->name,
            'description' => $pizza->description,
            'price' => $pizza->price,
            'recipeText' => $pizza->recipeText,
            'idCategory' => $pizza->category->id
        ]);

        $pizza->id = $this->getPdo()->lastInsertId();

        foreach ($pizza->ingredients as $ingredient)
        {
            $this->ingredientRepository->createIngredient($ingredient,$pizza->id);
        }

        // Retourner l'ID de la pizza insérée
        return $pizza->id;
    }

    public function updatePizza(Pizza $pizza): bool
    {
        $query = "UPDATE Pizza SET name = :name, description = :description, price = :price, recipeText = :recipeText, idCategory = :idCategory WHERE id = :id";
        $statement = $this->getPdo()->prepare($query);
        $statement->execute([
            'id' => $pizza->id,
            'name' => $pizza->name,
            'description' => $pizza->description,
            'price' => $pizza->price,
            'recipeText' => $pizza->recipeText,
            'idCategory' => $pizza->category->id
        ]);

        // Vérifier si la pizza a été mise à jour avec succès
        return $statement->rowCount() > 0;
    }
}

?>